; A statement ends with a semicolon, characters on a line after the semicolon are ignored
; lines starting with a semicolon are treated as comments

drop table if exists configuration;
drop table if exists report;
drop table if exists planet;
drop table if exists player;
drop table if exists alliance;
drop table if exists account;

create table configuration (
    MAINFRAMEWIDTH	INT,
    MAINFRAMEHEIGHT	INT,
    GALAXYWIDTH		INT,
    GALAXYHEIGHT	INT,
	SHOWGALAXY		BOOLEAN,
	USECLIPBOARD	BOOLEAN,
	FONTNAME		VARCHAR(100) CHARACTER SET utf8,
	FONTSIZE		INT
) ENGINE=INNODB;

create table account (
    ID          BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    NAME        VARCHAR(50) CHARACTER SET utf8 COLLATE utf8_bin UNIQUE,
	ISDEFAULT	BOOLEAN,
	SEQUENCE	INT,
    LANGUAGE    VARCHAR(20),
    FLAVOR      VARCHAR(20)
) ENGINE=INNODB;

create table alliance (
    ID          BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    ACCOUNT     BIGINT NOT NULL,
	ALLIANCEID	BIGINT NOT NULL,
    NAME        VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_bin,
	TAG			VARCHAR(30),
    UPDATETIME  BIGINT,
	NOTES		TEXT,
    FOREIGN KEY(ACCOUNT) REFERENCES account(ID) ON DELETE CASCADE
) ENGINE=INNODB, DEFAULT CHARACTER SET utf8;

create unique index allianceIndex on alliance (ACCOUNT, ALLIANCEID);
create index allianceNameIndex on alliance (NAME);
create index tagIndex on alliance (TAG);

create table player (
    ID          BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    ACCOUNT     BIGINT NOT NULL,
    NAME        VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_bin,
    TITLE       VARCHAR(3000) CHARACTER SET utf8 COLLATE utf8_bin,
	PLAYERID	BIGINT NOT NULL,
    ALLIANCE    BIGINT,
    POINTS             BIGINT,
    POINTSBUILDINGS    BIGINT,
    POINTSFLEET        BIGINT,
    POINTSRESEARCH     BIGINT,
    POINTSACHIEVEMENTS BIGINT,
    PLACE              BIGINT,
    PLACEBUILDINGS     BIGINT,
    PLACEFLEET         BIGINT,
    PLACERESEARCH      BIGINT,
    PLACEACHIEVEMENTS  BIGINT,
    UPDATETIME  BIGINT,
	STATUS		VARCHAR(20),
	SECSTATUS	VARCHAR(20),
	NOTES		TEXT,
    FOREIGN KEY(ACCOUNT) REFERENCES account(ID) ON DELETE CASCADE,
    FOREIGN KEY(ALLIANCE) REFERENCES alliance(ID) ON DELETE CASCADE
) ENGINE=INNODB, DEFAULT CHARACTER SET utf8;

create unique index playerIndex on player (ACCOUNT, PLAYERID);
create index playerNameIndex on player (NAME);
create index pointIndex on player (POINTS);

create table planet (
    ID          BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    ACCOUNT     BIGINT NOT NULL,
    NAME        VARCHAR(255),
    POSITION    INT NOT NULL,
	HASASTEROID	BOOLEAN,
	EVENT		BOOLEAN,
    OWNER	    BIGINT,
    UPDATETIME  BIGINT,
	NOTES		TEXT,
    IRON		BIGINT,
    METAL		BIGINT,
    KRYPTONITE	BIGINT,
    SPICE		BIGINT,
    FOREIGN KEY(ACCOUNT) REFERENCES account(ID) ON DELETE CASCADE,
    FOREIGN KEY(OWNER) REFERENCES player(ID) ON DELETE CASCADE
) ENGINE=INNODB, DEFAULT CHARACTER SET utf8;

create unique index planetIndex on planet (POSITION, ACCOUNT);
create index ownerIndex on planet (OWNER);
create index timeIndex on planet (UPDATETIME);

create table report (
    ID          BIGINT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    KIND     	VARCHAR(10),
    ACCOUNT     BIGINT NOT NULL,
    CREATETIME  BIGINT NOT NULL,
    POSITION    INT NOT NULL,
	ISASTEROID	BOOLEAN,
    PRIORITY   	VARCHAR(20),
	REPORTDATA	TEXT,
	NOTES		TEXT,
    ATTACKER    VARCHAR(100),
    DEFENDER    VARCHAR(100),
    PLANET      VARCHAR(100),
    FOREIGN KEY(ACCOUNT) REFERENCES account(ID) ON DELETE CASCADE
) ENGINE=INNODB, DEFAULT CHARACTER SET utf8;

create index reportIndex on report (POSITION, ACCOUNT, CREATETIME);
